CSES - Data Structures and Algorithms spring 2024 - Tasks

Login using mooc.fi — Dark mode

## General

Deadline: N/A

- Rules for the course

## Week 1

Deadline: 2024-03-10 23:59:59

- Candies
- Inversions
- Same bits
- Repeat
- Efficiency test
- Sequence of numbers
- Time complexities
- Rectangles

## Week 2

Deadline: 2024-03-10 23:59:59

- List efficiency I
- List efficiency II
- List incrementing
- Different sums
- Circle game
- Two lists
- Nested list
- Inversions again

## Week 3

Deadline: 2024-03-10 23:59:59

- Same bit
- Same character
- Forbidden character
- Lone number
- List split
- Tira sequences
- Last number
- Stock trading

## Week 4

Deadline: 2024-03-10 23:59:59

- Robot route
- No pair
- Same distance
- Play lists
- Big win
- Same hash
- Sublists
- Long route

## Week 5

Deadline: 2024-03-10 23:59:59

- Packing
- Contiguous numbers
- Sorting algorithms
- Binary search
- Largest distance
- Restaurant
- Semisorting
- Swap and move

## Week 6

Deadline: 2024-03-10 23:59:59

- Max list
- Repeat list
- Fast mode
- Mex numbers
- Quick list
- Different repeats
- Sum of squares
- Near list

## Week 7

Deadline: 2024-03-10 23:59:59

- Leaves
- No branch
- Children
- Depths
- Same depth
- Subtrees
- Queens
- All Trees

## Week 8

Deadline: 2024-03-10 23:59:59

- End of course
- Components
- Cities
- Computer network
- Chambers
- Labyrinth
- Coloring
- Push box

## Week 9

Deadline: 2024-05-12 23:59:59

- Choice of sum
- Subsets
- Balanced parenthesis
- Anagrams
- Odd lists
- Fast coins
- Not adjacent
- More coins

## Week 10

Deadline: 2024-05-12 23:59:59

- Most coins
- Subsequence construction
- Efficiency of a formula
- All subsequences
- Removing recursion
- Smallest count
- Bit erase
- Course

## Week 11

Deadline: 2024-05-12 23:59:59

- Changing list
- Efficiency of deque
- Smallest on a list
- Smallest elements
- Flip list
- Median
- Full round
- Small sums

## Week 12

Deadline: 2024-05-12 23:59:59

- Set size
- Tree height
- Order of addition
- Min and max
- Prev and next
- Remove an element
- Many elements
- AVL tree

## Week 13

Deadline: 2024-05-12 23:59:59

- Topological ordering
- Strong connectivity
- Course plan
- Number of paths
- Airports
- All paths
- Graph game
- Paths

## Week 14

Deadline: 2024-05-12 23:59:59

- Bellman–Ford algorithm
- Dijkstra's algorithm
- Best route
- Train prices
- List jump
- Grid path
- Wall breaking
- Measuring water

## Week 15

Deadline: 2024-05-12 23:59:59

- Minimum spanning tree
- Maximum spanning tree
- Components
- New Roads
- Largest set
- Same weight
- Walls and floors
- All trees

## Week 16

Deadline: 2024-05-12 23:59:59

- End of course
- Maximum flow
- Download
- Planets
- Ball
- Knight pairs
- New walls
- Coin grid